DartDrmService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkUrlExpiration(
DrmStreamUrls drmUrls) → bool -
fromJsonString(
String jsonString) → DrmSessionData -
generateDrmStreamUrls(
{required DrmSessionData sessionData, required String streamType, required String quality}) → DrmStreamUrls -
generateSession(
{required String apiKey, required String userId, required String videoId, required String platform}) → Future< String> -
getSupportedQualities(
) → List< String> -
getSupportedStreamTypes(
) → List< String> -
getTimeUntilExpiration(
DrmStreamUrls drmUrls) → int -
parseSessionResponse(
String sessionJson) → DrmSessionData -
testSignatureGeneration(
{required String privateKeyBase64, required String testDataHex}) → String -
validateStreamConfig(
{required String streamType, required String quality}) → bool