VideoPlayerController class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose()
→ void
-
-
getCurrentPosition()
→ Future<Duration>
-
-
getDuration()
→ Future<Duration>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pause()
→ Future<void>
-
-
play()
→ Future<void>
-
-
seekTo(Duration position)
→ Future<void>
-
-
setDrmConfig({required String videoUrl, required String licenseUrl, String? signingKey, String? edgeName, String? token, String? kid, double? width, double? height, String? alignment, String? certificateUrl})
→ Future<void>
-
-
setPlaybackSpeed(double speed)
→ Future<void>
-
-
setUrl(String url, {String? signingKey})
→ Future<void>
-
-
setVolume(double volume)
→ Future<void>
-
-
setWatermarkConfig(WatermarkConfig config)
→ Future<void>
-
-
stop()
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited